models_dir

Function models_dir 

pub fn models_dir() -> PathBuf
Shared model cache directory. On first use, migrate the legacy model cache out of the durable data directory when a same-filesystem rename is possible.