pub fn ensure_branch(conn: &mut Connection<'_>, branch: &str) -> Result<()>Expand description
Create the node and edge tables for branch if they don’t already exist.
Safe to call on every operation — idempotent.
pub fn ensure_branch(conn: &mut Connection<'_>, branch: &str) -> Result<()>Create the node and edge tables for branch if they don’t already exist.
Safe to call on every operation — idempotent.